# Contribution guidelines

## Contact

For questions about these guidelines, code style, conventions,
and Python please pester maybetree.

For quesitons about the backend, science, and C++,
please pester arendMoerman.

## Guidelines

- The `main` branch is protected. You cannot push directly to it.
    - If you want to contribute, make a branch
        with your changes, and then make a pull request.

- Follow PEP8.

- Install ruff (`pip install ruff`) and run it
    (`ruff check` from the root of the repo)
    to make sure you don't have any style guide violations.

